# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHARM_RM_METADATA = Metadata(
    id="3471ff0ec6dbd4a22174fb3104b742b5fc9fd86b.boutiques",
    name="spharm_rm",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SpharmRmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spharm_rm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output image file generated by spharm_rm"""


def spharm_rm(
    input_file: InputPathType,
    output_file: str,
    mask_file: InputPathType | None = None,
    number_of_terms: float | None = None,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> SpharmRmOutputs:
    """
    Part of FSL - Spherical harmonics removal tool to process neuroimaging data.
    
    Author: University of Oxford (Mark Jenkinson)
    
    Args:
        input_file: Input image filename.
        output_file: Output image filename.
        mask_file: Mask filename.
        number_of_terms: Number of terms to remove (order is\
            1,x,y,z,z^2+(x^2+y^2)/2,zx,zy,xy,x^2-y^2).
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpharmRmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHARM_RM_METADATA)
    cargs = []
    cargs.append("spharm_rm")
    cargs.extend([
        "--in",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--out",
        output_file
    ])
    if mask_file is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask_file)
        ])
    if number_of_terms is not None:
        cargs.extend([
            "-n",
            str(number_of_terms)
        ])
    if verbose_flag:
        cargs.append("--verbose")
    ret = SpharmRmOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHARM_RM_METADATA",
    "SpharmRmOutputs",
    "spharm_rm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DRIVE_SUMA_METADATA = Metadata(
    id="8732e38f8accb3657c2bb8658171028fb32be588.boutiques",
    name="DriveSuma",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DriveSumaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `drive_suma(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def drive_suma(
    command: str,
    runner: Runner | None = None,
) -> DriveSumaOutputs:
    """
    A program to drive suma from the command line.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/DriveSuma.html
    
    Args:
        command: Command to be sent to SUMA.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DriveSumaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DRIVE_SUMA_METADATA)
    cargs = []
    cargs.append("DriveSuma")
    cargs.append("[INPUT_FILE]")
    cargs.append("-com")
    cargs.append(command)
    cargs.append("[ADDITIONAL_OPTIONS]")
    ret = DriveSumaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DRIVE_SUMA_METADATA",
    "DriveSumaOutputs",
    "drive_suma",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_FDR_METADATA = Metadata(
    id="455e991e6fc8b7d57aae157ffd2294a4ca4ed068.boutiques",
    name="3dFDR",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dFdrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_fdr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik: OutputPathType
    """Output dataset in BRIK format"""
    output_head: OutputPathType
    """Output dataset in HEAD format"""
    output_1d: OutputPathType
    """Output list of voxel q-values"""


def v_3d_fdr(
    input_file: InputPathType,
    prefix: str,
    mask_file: InputPathType | None = None,
    mask_threshold: float | None = None,
    constant_type: typing.Literal["cind", "cdep"] | None = None,
    quiet: bool = False,
    list_: bool = False,
    mode_option: typing.Literal["old", "new"] | None = None,
    pmask: bool = False,
    nopmask: bool = False,
    force: bool = False,
    float_: bool = False,
    qval: bool = False,
    runner: Runner | None = None,
) -> V3dFdrOutputs:
    """
    A tool for applying False Discovery Rate (FDR) thresholding to voxelwise
    statistics in 3D functional datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dFDR.html
    
    Args:
        input_file: Input 3D functional dataset filename.
        prefix: Use 'pname' for the output dataset prefix name.
        mask_file: Use mask values from file mname. If file mname contains more\
            than 1 sub-brick, the mask sub-brick must be specified. Generally\
            should be used to avoid counting non-brain voxels.
        mask_threshold: Only voxels whose corresponding mask value is greater\
            than or equal to the specified value in absolute terms will be\
            considered. Default is 1.
        constant_type: Set constant c(N): 1 for independent p-values (default)\
            or sum(1/i, i=1,...,N) for any joint distribution.
        quiet: Suppress screen output.
        list_: Write sorted list of voxel q-values to screen.
        mode_option: Use the old or new mode of operation. 'new' is now the\
            default.
        pmask: Ignore p=1 voxels (default in new mode).
        nopmask: Count p=1 voxels (default in old mode).
        force: Force conversion of all sub-bricks, treating them as p-values.
        float_: Force the output of z-scores in floating point format.
        qval: Force the output of q-values rather than z-scores.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dFdrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_FDR_METADATA)
    cargs = []
    cargs.append("3dFDR")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    if mask_file is not None:
        cargs.extend([
            "-mask_file",
            execution.input_file(mask_file)
        ])
    if mask_threshold is not None:
        cargs.extend([
            "-mask_thr",
            str(mask_threshold)
        ])
    if constant_type is not None:
        cargs.extend([
            "-c",
            constant_type
        ])
    if quiet:
        cargs.append("-quiet")
    if list_:
        cargs.append("-list")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if mode_option is not None:
        cargs.extend([
            "-",
            mode_option
        ])
    if pmask:
        cargs.append("-pmask")
    if nopmask:
        cargs.append("-nopmask")
    if force:
        cargs.append("-force")
    if float_:
        cargs.append("-float")
    if qval:
        cargs.append("-qval")
    ret = V3dFdrOutputs(
        root=execution.output_file("."),
        output_brik=execution.output_file(prefix + "+orig.BRIK"),
        output_head=execution.output_file(prefix + "+orig.HEAD"),
        output_1d=execution.output_file(prefix + ".1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dFdrOutputs",
    "V_3D_FDR_METADATA",
    "v_3d_fdr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_MRS_PROC_METADATA = Metadata(
    id="fb3a400f171c0088382986998ebb6b0485571ba6.boutiques",
    name="fsl_mrs_proc",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslMrsProcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_mrs_proc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_mrs_proc(
    runner: Runner | None = None,
) -> FslMrsProcOutputs:
    """
    FSL Magnetic Resonance Spectroscopy - Preprocessing.
    
    Author: FMRIB Centre, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslMrsProcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_MRS_PROC_METADATA)
    cargs = []
    cargs.append("fsl_mrs_proc")
    cargs.append("[GLOBAL_OPTIONS]")
    cargs.append("<subcommand>")
    cargs.append("[SUBCOMMAND_OPTIONS]")
    ret = FslMrsProcOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_MRS_PROC_METADATA",
    "FslMrsProcOutputs",
    "fsl_mrs_proc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NWARP_CAT_METADATA = Metadata(
    id="c34b27345b5662d5255d72d5b42d79c401a41ba7.boutiques",
    name="3dNwarpCat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNwarpCatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_nwarp_cat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix: OutputPathType
    """Output matrix file when only matrix warps are provided."""
    output_dataset: OutputPathType
    """Output dataset when warp files are provided."""


def v_3d_nwarp_cat(
    output_prefix: str,
    warp1: InputPathType,
    warp2: InputPathType,
    interpolation: str | None = None,
    verbosity: bool = False,
    space_marker: str | None = None,
    additional_warps: list[InputPathType] | None = None,
    invert_final_warp: bool = False,
    extra_padding: float | None = None,
    runner: Runner | None = None,
) -> V3dNwarpCatOutputs:
    """
    Catenates (composes) 3D warps defined on a grid or via a matrix.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dNwarpCat.html
    
    Args:
        output_prefix: Prefix name for the output dataset that holds the warp.
        warp1: Specify the first warp.
        warp2: Specify the second warp.
        interpolation: Interpolation mode: linear, quintic, or wsinc5\
            (default).
        verbosity: Print various fun messages during execution.
        space_marker: Attach string 'sss' to the output dataset as its atlas\
            space marker.
        additional_warps: Additional warp files.
        invert_final_warp: Invert the final warp before output.
        extra_padding: Pad the nonlinear warps by 'PP' voxels in all\
            directions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNwarpCatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NWARP_CAT_METADATA)
    cargs = []
    cargs.append("3dNwarpCat")
    if interpolation is not None:
        cargs.extend([
            "-interp",
            interpolation
        ])
    if verbosity:
        cargs.append("-verb")
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if space_marker is not None:
        cargs.extend([
            "-space",
            space_marker
        ])
    cargs.append("-warp1")
    cargs.extend([
        "-warp1",
        execution.input_file(warp1)
    ])
    cargs.append("-warp2")
    cargs.extend([
        "-warp2",
        execution.input_file(warp2)
    ])
    if additional_warps is not None:
        cargs.extend([execution.input_file(f) for f in additional_warps])
    if invert_final_warp:
        cargs.append("-iwarp")
    if extra_padding is not None:
        cargs.extend([
            "-expad",
            str(extra_padding)
        ])
    ret = V3dNwarpCatOutputs(
        root=execution.output_file("."),
        output_matrix=execution.output_file(output_prefix + ".aff12.1D"),
        output_dataset=execution.output_file(output_prefix + "+tlrc.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNwarpCatOutputs",
    "V_3D_NWARP_CAT_METADATA",
    "v_3d_nwarp_cat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMSTACK_METADATA = Metadata(
    id="d9773a0d9f7ba95b29bbf436cd06818e5ff885f9.boutiques",
    name="imstack",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImstackOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imstack(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_data_file: OutputPathType | None
    """Output data file"""
    output_header_file: OutputPathType | None
    """Output header file"""


def imstack(
    image_files: list[InputPathType],
    data_type: typing.Literal["short", "float"] | None = None,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> ImstackOutputs:
    """
    Stacks up a set of 2D images into one big file (a la MGH).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/imstack.html
    
    Args:
        image_files: Input image filenames.
        data_type: Converts the output data file to be 'type', which is either\
            'short' or 'float'. The default type is the type of the first image.
        output_prefix: Names the output files to be 'name'.b'type' and\
            'name'.hdr. The default name is 'obi-wan-kenobi'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImstackOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMSTACK_METADATA)
    cargs = []
    cargs.append("imstack")
    cargs.extend([execution.input_file(f) for f in image_files])
    if data_type is not None:
        cargs.extend([
            "-datum",
            data_type
        ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    ret = ImstackOutputs(
        root=execution.output_file("."),
        output_data_file=execution.output_file(output_prefix + ".b" + data_type) if (output_prefix is not None and data_type is not None) else None,
        output_header_file=execution.output_file(output_prefix + ".hdr") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMSTACK_METADATA",
    "ImstackOutputs",
    "imstack",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CONVOLVE_METADATA = Metadata(
    id="ff0b579532efd672514820c906ac0bdc7220511d.boutiques",
    name="3dConvolve",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dConvolveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_convolve(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Main output file of 3dConvolve"""


def v_3d_convolve(
    infile: InputPathType,
    outfile: str,
    options: str | None = None,
    runner: Runner | None = None,
) -> V3dConvolveOutputs:
    """
    3dConvolve is no longer supported in AFNI.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dConvolve.html
    
    Args:
        infile: Input file for 3dConvolve.
        outfile: Output file for 3dConvolve.
        options: Additional options for 3dConvolve.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dConvolveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CONVOLVE_METADATA)
    cargs = []
    cargs.append("3dConvolve")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    if options is not None:
        cargs.extend([
            "-options",
            options
        ])
    ret = V3dConvolveOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dConvolveOutputs",
    "V_3D_CONVOLVE_METADATA",
    "v_3d_convolve",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STRBLAST_METADATA = Metadata(
    id="5d0ef9b106739ab35046cccfe77a8538e51aeb84.boutiques",
    name="strblast",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class StrblastOutputs(typing.NamedTuple):
    """
    Output object returned when calling `strblast(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def strblast(
    runner: Runner | None = None,
) -> StrblastOutputs:
    """
    Finds exact copies of the target string in each of the input files, and replaces
    all characters with some junk string.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/strblast.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `StrblastOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STRBLAST_METADATA)
    cargs = []
    cargs.append("strblast")
    cargs.append("[OPTIONS]")
    cargs.append("TARGETSTRING")
    cargs.append("[INPUT_FILES...]")
    ret = StrblastOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STRBLAST_METADATA",
    "StrblastOutputs",
    "strblast",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APPLYWARP_METADATA = Metadata(
    id="feff959ede39bc32c46956ed391232146e709478.boutiques",
    name="applywarp",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ApplywarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `applywarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_output_file: OutputPathType
    """Warped output image"""


def applywarp(
    input_file: InputPathType,
    output_file: str,
    reference_file: InputPathType,
    warp_coeff_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> ApplywarpOutputs:
    """
    Apply a warp to an image using FSL's applywarp utility.
    
    Author: University of Oxford (Jesper Andersson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FNIRT/Applywarp
    
    Args:
        input_file: Filename of input image (to be warped).
        output_file: Filename for output (warped) image.
        reference_file: Filename for reference image.
        warp_coeff_file: Filename for warp/coefficient (volume).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ApplywarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APPLYWARP_METADATA)
    cargs = []
    cargs.append("applywarp")
    cargs.append("-i")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.append("-o")
    cargs.extend([
        "-o",
        output_file
    ])
    cargs.append("-r")
    cargs.extend([
        "-r",
        execution.input_file(reference_file)
    ])
    cargs.append("-w")
    if warp_coeff_file is not None:
        cargs.extend([
            "-w",
            execution.input_file(warp_coeff_file)
        ])
    cargs.append("--usesqform")
    ret = ApplywarpOutputs(
        root=execution.output_file("."),
        warped_output_file=execution.output_file(output_file + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APPLYWARP_METADATA",
    "ApplywarpOutputs",
    "applywarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DKMEANS_METADATA = Metadata(
    id="3a4bcacba0796e3087ac57c6df380dbd644dc61d.boutiques",
    name="3dkmeans",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dkmeansOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dkmeans(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cluster_membership: OutputPathType
    """Output volume for the cluster membership."""
    cluster_distance: OutputPathType
    """Output volume for the cluster distance measures."""
    distances_text_file: OutputPathType
    """Output text file containing distances between clusters."""
    centroids_text_file: OutputPathType
    """Output text file containing cluster centroids."""
    within_cluster_sum_text_file: OutputPathType
    """Output text file containing within cluster sum of distances."""
    max_distance_text_file: OutputPathType
    """Output text file containing maximum distance within each cluster."""
    voxel_distance_to_centroid: OutputPathType
    """Output text file containing distance from voxel to its centroid."""


def v_3dkmeans(
    runner: Runner | None = None,
) -> V3dkmeansOutputs:
    """
    3d+t Clustering segmentation based on The C clustering library.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dkmeans.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dkmeansOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DKMEANS_METADATA)
    cargs = []
    cargs.append("3dkmeans")
    cargs.append("[OPTIONS]")
    ret = V3dkmeansOutputs(
        root=execution.output_file("."),
        cluster_membership=execution.output_file("[JOBNAME]_membership.nii.gz"),
        cluster_distance=execution.output_file("[JOBNAME]_distance.nii.gz"),
        distances_text_file=execution.output_file("FILE.dis.1D"),
        centroids_text_file=execution.output_file("FILE.cen.1D"),
        within_cluster_sum_text_file=execution.output_file("FILE.info1.1D"),
        max_distance_text_file=execution.output_file("FILE.info2.1D"),
        voxel_distance_to_centroid=execution.output_file("FILE.vcd.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dkmeansOutputs",
    "V_3DKMEANS_METADATA",
    "v_3dkmeans",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DVOLREG_METADATA = Metadata(
    id="5cc2663dc96c9972a79c75185488f6362ed7420f.boutiques",
    name="3dvolreg",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dvolregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dvolreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    md1d_file: OutputPathType
    """Max displacement output file."""
    oned_file: OutputPathType
    """1d movement parameters output file."""
    oned_matrix_save: OutputPathType
    """Save the matrix transformation."""
    out_file: OutputPathType
    """Output image file name."""
    md1d_file_: OutputPathType
    """Max displacement info file."""
    oned_file_: OutputPathType
    """Movement parameters info file."""
    oned_matrix_save_: OutputPathType
    """Matrix transformation from base to input."""
    out_file_: OutputPathType
    """Registered file."""


def v_3dvolreg(
    in_file: InputPathType,
    basefile: InputPathType | None = None,
    zpad: int | None = None,
    copyorigin: bool = False,
    in_weight_volume_2: InputPathType | None = None,
    interp: typing.Literal["Fourier", "cubic", "heptic", "quintic", "linear"] | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    timeshift: bool = False,
    verbose: bool = False,
    runner: Runner | None = None,
) -> V3dvolregOutputs:
    """
    Register input volumes to a base volume using AFNI 3dvolreg command.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dvolreg.html
    
    Args:
        in_file: Input file to 3dvolreg.
        basefile: Base file for registration.
        zpad: Zeropad around the edges by 'n' voxels during rotations.
        copyorigin: Copy base file origin coords to output.
        in_weight_volume_2: (file or string, an integer) or file or string.\
            Weights for each voxel specified by a file with an optional volume\
            number (defaults to 0).
        interp: 'fourier' or 'cubic' or 'heptic' or 'quintic' or 'linear'.\
            Spatial interpolation methods [default = heptic].
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        timeshift: Time shift to mean slice time offset.
        verbose: More detailed description of the process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dvolregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DVOLREG_METADATA)
    cargs = []
    cargs.append("3dvolreg")
    if basefile is not None:
        cargs.extend([
            "-base",
            execution.input_file(basefile)
        ])
    if zpad is not None:
        cargs.extend([
            "-zpad",
            str(zpad)
        ])
    cargs.append("[MD1D_FILE]")
    cargs.append(execution.input_file(in_file))
    if copyorigin:
        cargs.append("-twodup")
    if in_weight_volume_2 is not None:
        cargs.extend([
            "-weight '",
            execution.input_file(in_weight_volume_2)
        ])
    if interp is not None:
        cargs.extend([
            "-",
            interp
        ])
    cargs.append("[ONED_FILE]")
    cargs.append("[ONED_MATRIX_SAVE]")
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    if timeshift:
        cargs.append("-tshift 0")
    if verbose:
        cargs.append("-verbose")
    ret = V3dvolregOutputs(
        root=execution.output_file("."),
        md1d_file=execution.output_file(pathlib.Path(in_file).name + "_md.1D"),
        oned_file=execution.output_file(pathlib.Path(in_file).name + ".1D"),
        oned_matrix_save=execution.output_file(pathlib.Path(in_file).name + ".aff12.1D"),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_volreg"),
        md1d_file_=execution.output_file("md1d_file"),
        oned_file_=execution.output_file("oned_file"),
        oned_matrix_save_=execution.output_file("oned_matrix_save"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dvolregOutputs",
    "V_3DVOLREG_METADATA",
    "v_3dvolreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__PARSE_AFNI_NAME_METADATA = Metadata(
    id="12d1dff851d7fa23b8eb242b2486503f1c1932d3.boutiques",
    name="@parse_afni_name",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VParseAfniNameOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__parse_afni_name(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_path: OutputPathType
    """Output path parsed from the AFNI name"""
    output_prefix: OutputPathType
    """Output prefix parsed from the AFNI name"""
    output_view: OutputPathType
    """Output view parsed from the AFNI name"""
    output_subbrick: OutputPathType
    """Output sub-brick selection string parsed from the AFNI name"""


def v__parse_afni_name(
    afni_name: str,
    runner: Runner | None = None,
) -> VParseAfniNameOutputs:
    """
    A script to parse an AFNI name, outputting the path, prefix, view, and sub-brick
    selection string.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@parse_afni_name.html
    
    Args:
        afni_name: The AFNI name to be parsed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VParseAfniNameOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__PARSE_AFNI_NAME_METADATA)
    cargs = []
    cargs.append("@parse_afni_name")
    cargs.append(afni_name)
    ret = VParseAfniNameOutputs(
        root=execution.output_file("."),
        output_path=execution.output_file("parsed_name_path.txt"),
        output_prefix=execution.output_file("parsed_name_prefix.txt"),
        output_view=execution.output_file("parsed_name_view.txt"),
        output_subbrick=execution.output_file("parsed_name_subbrick.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VParseAfniNameOutputs",
    "V__PARSE_AFNI_NAME_METADATA",
    "v__parse_afni_name",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_ASTRIP_METADATA = Metadata(
    id="9068ca7039fa3defb693625b26ce4071a91d5347.boutiques",
    name="1dAstrip",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dAstripOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_astrip(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file with only numeric characters."""


def v_1d_astrip(
    infile: InputPathType,
    runner: Runner | None = None,
) -> V1dAstripOutputs:
    """
    Strips non-numeric characters from a file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dAstrip.html
    
    Args:
        infile: Input file from which non-numeric characters will be stripped.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dAstripOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_ASTRIP_METADATA)
    cargs = []
    cargs.append("1dAstrip")
    cargs.append("<" + "< " + execution.input_file(infile) + ">")
    cargs.append("[OUTPUT_FILE]")
    ret = V1dAstripOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dAstripOutputs",
    "V_1D_ASTRIP_METADATA",
    "v_1d_astrip",
]



"""
FreeSurfer

FreeSurfer is a software package for the analysis and visualization of
neuroimaging data from cross-sectional and longitudinal studies. It is developed
by the Laboratory for Computational Neuroimaging at the Martinos Center for
Biomedical Imaging.

FreeSurfer provides full processing streams for structural and functional MRI
and includes tools for linear and nonlinear registration, cortical and
subcortical segmentation, cortical surface reconstruction, statistical analysis
of group morphometry, diffusion MRI, PET analysis, and much more. It is also the
structural MRI analysis software of choice for the Human Connectome Project.

URL: https://github.com/freesurfer/freesurfer
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .apply_vol_transform import *
from .mri_binarize import *
from .mri_synthstrip import *
from .recon_all import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLCC_METADATA = Metadata(
    id="fdac683ed1b6cc2dfb8d023926091ca64a782436.boutiques",
    name="fslcc",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslccOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslcc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslcc(
    first_input: InputPathType,
    second_input: InputPathType,
    mask: InputPathType | None = None,
    noabs_flag: bool = False,
    nodemean_flag: bool = False,
    threshold: float | None = 0.1,
    decimal_places: float | None = 2,
    runner: Runner | None = None,
) -> FslccOutputs:
    """
    Cross-correlate two time-series, timepoint by timepoint.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FSL
    
    Args:
        first_input: First input time-series.
        second_input: Second input time-series.
        mask: Mask file name.
        noabs_flag: Don't return absolute values (keep sign).
        nodemean_flag: Don't demean the input files.
        threshold: Threshold (default 0.1).
        decimal_places: Number of decimal places to display in output (default\
            2).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslccOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLCC_METADATA)
    cargs = []
    cargs.append("fslcc")
    cargs.append(execution.input_file(first_input))
    cargs.append(execution.input_file(second_input))
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if noabs_flag:
        cargs.append("--noabs")
    if nodemean_flag:
        cargs.append("--nodemean")
    if threshold is not None:
        cargs.extend([
            "-t",
            str(threshold)
        ])
    if decimal_places is not None:
        cargs.extend([
            "-p",
            str(decimal_places)
        ])
    ret = FslccOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLCC_METADATA",
    "FslccOutputs",
    "fslcc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIENA_FLOW2STD_METADATA = Metadata(
    id="5c1a16e6112cdc424ccf2cc9d634a11727d98160.boutiques",
    name="siena_flow2std",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SienaFlow2stdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `siena_flow2std(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def siena_flow2std(
    fileroot1: str,
    fileroot2: str,
    sigma: float | None = 5,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> SienaFlow2stdOutputs:
    """
    Convert edge flow to standard space.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        fileroot1: Input file root 1.
        fileroot2: Input file root 2.
        sigma: Spatial smoothing of standard-space edge-flow image, sigma\
            (HWHM) in mm (default=5).
        debug_flag: Debug (don't delete intermediate files).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SienaFlow2stdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIENA_FLOW2STD_METADATA)
    cargs = []
    cargs.append("siena_flow2std")
    cargs.append(fileroot1)
    cargs.append(fileroot2)
    if sigma is not None:
        cargs.extend([
            "-s",
            str(sigma)
        ])
    if debug_flag:
        cargs.append("-d")
    ret = SienaFlow2stdOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIENA_FLOW2STD_METADATA",
    "SienaFlow2stdOutputs",
    "siena_flow2std",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TTOZ_METADATA = Metadata(
    id="a909a0eee6e1f0850e3a86e6e4ffa8ff91713090.boutiques",
    name="ttoz",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class TtozOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ttoz(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_zvol: OutputPathType
    """Output Z-statistic volume"""


def ttoz(
    runner: Runner | None = None,
) -> TtozOutputs:
    """
    Tool to convert a T-statistic image to a Z-statistic image.
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TtozOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TTOZ_METADATA)
    cargs = []
    cargs.append("ttoz")
    cargs.append("[OPTIONS]")
    cargs.append("<varsfile>")
    cargs.append("<cbsfile>")
    cargs.append("<dof>")
    ret = TtozOutputs(
        root=execution.output_file("."),
        output_zvol=execution.output_file("[OUTPUTVOL].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TTOZ_METADATA",
    "TtozOutputs",
    "ttoz",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PTA_METADATA = Metadata(
    id="d9f63e36aafd8371cada695ede0d9af6d689a660.boutiques",
    name="PTA",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PtaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pta(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stat_output: OutputPathType
    """Statistical evidence output of PTA"""
    prediction_output: OutputPathType
    """Predicted values and their standard errors"""


def pta(
    prefix: str,
    input_file: InputPathType,
    model_formula: str,
    vt_formulation: str | None = None,
    prediction_table: InputPathType | None = None,
    verbosity_level: float | None = None,
    response_var: str | None = None,
    dbg_args: bool = False,
    runner: Runner | None = None,
) -> PtaOutputs:
    """
    Program for Profile Tracking Analysis - estimates nonlinear trajectories through
    smoothing splines.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/PTA.html
    
    Args:
        prefix: Prefix for output files.
        input_file: Input data file in table format (data frame structure of\
            long format in R).
        model_formula: Model formulation through multilevel smoothing splines.
        vt_formulation: Specify varying smoothing terms. Two components are\
            required: the first one 'var' indicates the variable (e.g., subject)\
            around which the smoothing will vary while the second component\
            specifies the smoothing formulation (e.g., s(age,subject)).
        prediction_table: Data table to generate predicted values for graphical\
            illustration.
        verbosity_level: Verbosity level (0 for quiet, 1 or more for talkative).
        response_var: Column name designated as the response/outcome variable\
            (default is 'Y').
        dbg_args: Enable R to save parameters for debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PtaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PTA_METADATA)
    cargs = []
    cargs.append("PTA")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-model",
        model_formula
    ])
    if vt_formulation is not None:
        cargs.extend([
            "-vt",
            vt_formulation
        ])
    if prediction_table is not None:
        cargs.extend([
            "-prediction",
            execution.input_file(prediction_table)
        ])
    if verbosity_level is not None:
        cargs.extend([
            "-verb",
            str(verbosity_level)
        ])
    if response_var is not None:
        cargs.extend([
            "-Y",
            response_var
        ])
    if dbg_args:
        cargs.append("-dbgArgs")
    ret = PtaOutputs(
        root=execution.output_file("."),
        stat_output=execution.output_file(prefix + "-stat.txt"),
        prediction_output=execution.output_file(prefix + "-prediction.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PTA_METADATA",
    "PtaOutputs",
    "pta",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_PATCH_METADATA = Metadata(
    id="bf694ee441e47bf6b816bf09ad6bc2d315d5f013.boutiques",
    name="SurfPatch",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfPatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_patch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outpatch_a: OutputPathType
    """Output patch for surface A"""
    outpatch_b: OutputPathType
    """Output patch for surface B"""
    out_stitched_surface: OutputPathType
    """Stitched surface file"""


def surf_patch(
    spec_file: InputPathType,
    surf_b: InputPathType,
    surf_b_: InputPathType,
    nodefile: InputPathType,
    inode: float,
    ilabel: float,
    prefix: str,
    runner: Runner | None = None,
) -> SurfPatchOutputs:
    """
    Creates a patch of surface formed by nodes in a nodefile and optionally
    calculates the volume between the same patch on two isotopic surfaces.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfPatch.html
    
    Args:
        spec_file: Spec file containing input surfaces.
        surf_b: Input surface B.
        surf_b_: Input surface B.
        nodefile: File containing nodes defining the patch.
        inode: Index of the column containing the nodes.
        ilabel: Index of the column containing labels of the nodes in column\
            inode.
        prefix: Prefix of output patch.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfPatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_PATCH_METADATA)
    cargs = []
    cargs.append("SurfPatch")
    cargs.append("-spec")
    cargs.append(execution.input_file(spec_file))
    cargs.append("-surf_A")
    cargs.extend([
        "-surf_B",
        execution.input_file(surf_b)
    ])
    cargs.append("-surf_B")
    cargs.extend([
        "-surf_B",
        execution.input_file(surf_b_)
    ])
    cargs.append("-input")
    cargs.extend([
        "-input",
        execution.input_file(nodefile)
    ])
    cargs.append(str(inode))
    cargs.append(str(ilabel))
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.append("[OPTIONS]")
    ret = SurfPatchOutputs(
        root=execution.output_file("."),
        outpatch_a=execution.output_file(prefix + "_A"),
        outpatch_b=execution.output_file(prefix + "_B"),
        out_stitched_surface=execution.output_file(prefix + "_stitched"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_PATCH_METADATA",
    "SurfPatchOutputs",
    "surf_patch",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_COLOR_MAP_METADATA = Metadata(
    id="5b3d8115e0e545706bcf37b8ac3fc6319d6fe5d0.boutiques",
    name="MakeColorMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MakeColorMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_color_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    afni_hex_output_prefix: OutputPathType
    """Prefix for individual color values in AFNI Hex format."""
    palette_file_output: OutputPathType
    """Example palette file output."""


def make_color_map(
    runner: Runner | None = None,
) -> MakeColorMapOutputs:
    """
    Utility for creating and modifying colormaps with various formats and fiducial
    points.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/MakeColorMap.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeColorMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_COLOR_MAP_METADATA)
    cargs = []
    cargs.append("MakeColorMap")
    cargs.append("[OPTIONS]")
    ret = MakeColorMapOutputs(
        root=execution.output_file("."),
        afni_hex_output_prefix=execution.output_file("[PREFIX]_01"),
        palette_file_output=execution.output_file("TestPalette.pal"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_COLOR_MAP_METADATA",
    "MakeColorMapOutputs",
    "make_color_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DIFF_TREE_METADATA = Metadata(
    id="24b1cfac6f49e5c4ce8deeb925305286098b7e84.boutiques",
    name="@diff.tree",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDiffTreeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__diff_tree(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__diff_tree(
    runner: Runner | None = None,
) -> VDiffTreeOutputs:
    """
    Show file differences between 2 directories.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@diff.tree.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDiffTreeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DIFF_TREE_METADATA)
    cargs = []
    cargs.append("@diff.tree")
    cargs.append("[OPTIONS]")
    cargs.append("new_dir")
    cargs.append("old_dir")
    ret = VDiffTreeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDiffTreeOutputs",
    "V__DIFF_TREE_METADATA",
    "v__diff_tree",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MEICA_PY_METADATA = Metadata(
    id="2f2085cdf1dc498e1f0961ccc02af9f3e6bfe321.boutiques",
    name="meica.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MeicaPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `meica_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cleaned_bold: OutputPathType
    """Cleaned BOLD image after ME-ICA processing"""
    components_output: OutputPathType
    """Independent components result of ICA"""


def meica_py(
    infile: InputPathType,
    echo_times: str,
    affine: str,
    output_directory: str,
    components: float | None = None,
    talairach: bool = False,
    threshold: float | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> MeicaPyOutputs:
    """
    Multi-Echo Independent Component Analysis for fMRI denoising.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/meica.py.html
    
    Args:
        infile: Input image dataset (e.g. dataset.nii.gz).
        echo_times: Echo times (e.g. 15.0,30.0,45.0).
        affine: Affine registration matrix.
        output_directory: Output directory.
        components: Number of components for ICA.
        talairach: Apply standard Talairach transformation.
        threshold: Threshold value for masking.
        debug: Enable debug mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MeicaPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MEICA_PY_METADATA)
    cargs = []
    cargs.append("meica.py")
    cargs.append("-d")
    cargs.append(execution.input_file(infile))
    cargs.append("-e")
    cargs.append(echo_times)
    cargs.append("-a")
    cargs.append(affine)
    cargs.append("-o")
    cargs.append(output_directory)
    if components is not None:
        cargs.extend([
            "-c",
            str(components)
        ])
    if talairach:
        cargs.append("-t")
    if threshold is not None:
        cargs.extend([
            "--thresh",
            str(threshold)
        ])
    if debug:
        cargs.append("--debug")
    ret = MeicaPyOutputs(
        root=execution.output_file("."),
        cleaned_bold=execution.output_file(output_directory + "/cleaned_bold.nii.gz"),
        components_output=execution.output_file(output_directory + "/components.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MEICA_PY_METADATA",
    "MeicaPyOutputs",
    "meica_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NOTES_METADATA = Metadata(
    id="53682729e36019e38e5cec4e59bd809825f01661.boutiques",
    name="3dNotes",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNotesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_notes(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_notes(
    dataset: InputPathType,
    add_note: str | None = None,
    append_history: str | None = None,
    replace_history: str | None = None,
    delete_note: float | None = None,
    print_notes: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> V3dNotesOutputs:
    """
    A program to add, delete and show notes for AFNI datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dNotes.html
    
    Args:
        dataset: AFNI compatible dataset [required].
        add_note: Add the string 'str' to the list of notes.
        append_history: Append the string 'str' to the dataset's history. This\
            can only appear once on the command line.
        replace_history: Replace any existing history note with 'str'. This\
            option cannot be used with '-h'.
        delete_note: Deletes note number num.
        print_notes: Print to stdout the expanded notes.
        help_: Displays this help screen.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNotesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NOTES_METADATA)
    cargs = []
    cargs.append("3dNotes")
    if add_note is not None:
        cargs.extend([
            "-a",
            add_note
        ])
    if append_history is not None:
        cargs.extend([
            "-h",
            append_history
        ])
    if replace_history is not None:
        cargs.extend([
            "-HH",
            replace_history
        ])
    if delete_note is not None:
        cargs.extend([
            "-d",
            str(delete_note)
        ])
    if print_notes:
        cargs.append("-ses")
    if help_:
        cargs.append("-help")
    cargs.append(execution.input_file(dataset))
    ret = V3dNotesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNotesOutputs",
    "V_3D_NOTES_METADATA",
    "v_3d_notes",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APPLYTOPUP_METADATA = Metadata(
    id="796c87a5699f7d6e7a6f4c3d38e953899925bbd6.boutiques",
    name="applytopup",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ApplytopupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `applytopup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The output warped image."""


def applytopup(
    imain: list[InputPathType],
    datain: InputPathType,
    inindex: list[str],
    topup_: InputPathType,
    out: str,
    method: typing.Literal["jac", "lsr"] | None = None,
    interp: typing.Literal["trilinear", "spline"] | None = None,
    datatype: typing.Literal["char", "short", "int", "float", "double"] | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> ApplytopupOutputs:
    """
    applytopup applies corrections to images using the field estimates produced by
    topup.
    
    Author: University of Oxford (Jesper Andersson)
    
    Args:
        imain: Comma separated list of names of input image (to be corrected).
        datain: Name of text file with PE directions/times.
        inindex: Comma separated list of indices into --datain of the input\
            image (to be corrected).
        topup_: Name of field/movements (from topup).
        out: Basename for output (warped) image.
        method: Use jacobian modulation (jac) or least-squares resampling\
            (lsr), default=lsr.
        interp: Interpolation method {trilinear, spline}, default=spline.
        datatype: Force output data type [char short int float double].
        verbose: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ApplytopupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APPLYTOPUP_METADATA)
    cargs = []
    cargs.append("applytopup")
    cargs.append("--imain=" + ",".join([execution.input_file(f) for f in imain]))
    cargs.append("--datain=" + execution.input_file(datain))
    cargs.append("--inindex=" + ",".join(inindex))
    cargs.append("--topup=" + execution.input_file(topup_, resolve_parent=True))
    cargs.append("--out=" + out)
    if method is not None:
        cargs.append("--method=" + method)
    if interp is not None:
        cargs.append("--interp=" + interp)
    if datatype is not None:
        cargs.append("--datatype=" + datatype)
    if verbose:
        cargs.append("--verbose")
    ret = ApplytopupOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APPLYTOPUP_METADATA",
    "ApplytopupOutputs",
    "applytopup",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VECREG_METADATA = Metadata(
    id="6c7d48cef02fef3fe66c2282a3eb56099599fdb5.boutiques",
    name="vecreg",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class VecregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vecreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_output: OutputPathType
    """Output file of registered vector or tensor field"""


def vecreg(
    input_file: InputPathType,
    output_file: str,
    reference_volume: InputPathType,
    transform_file: InputPathType | None = None,
    verbose_flag: bool = False,
    help_flag: bool = False,
    secondary_affine: InputPathType | None = None,
    secondary_warp: InputPathType | None = None,
    interp_method: str | None = "trilinear",
    brain_mask: InputPathType | None = None,
    ref_brain_mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> VecregOutputs:
    """
    Vector Affine/NonLinear Transformation with Orientation Preservation.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT
    
    Args:
        input_file: Filename for input vector or tensor field.
        output_file: Filename for output registered vector or tensor field.
        reference_volume: Filename for reference (target) volume.
        transform_file: Filename for affine transformation matrix.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        secondary_affine: Filename for secondary affine matrix; if set, this\
            will be used for the rotation of the vector/tensor field.
        secondary_warp: Filename for secondary warp field; if set, this will be\
            used for the rotation of the vector/tensor field.
        interp_method: Interpolation method (nearestneighbour, trilinear\
            (default), sinc, or spline).
        brain_mask: Brain mask in input space.
        ref_brain_mask: Brain mask in output space (useful for speed up of\
            nonlinear registration).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VecregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VECREG_METADATA)
    cargs = []
    cargs.append("vecreg")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    cargs.extend([
        "-r",
        execution.input_file(reference_volume)
    ])
    if transform_file is not None:
        cargs.extend([
            "-t",
            execution.input_file(transform_file)
        ])
    if verbose_flag:
        cargs.append("-v")
    if help_flag:
        cargs.append("-h")
    if secondary_affine is not None:
        cargs.extend([
            "--rotmat",
            execution.input_file(secondary_affine)
        ])
    if secondary_warp is not None:
        cargs.extend([
            "--rotwarp",
            execution.input_file(secondary_warp)
        ])
    if interp_method is not None:
        cargs.extend([
            "--interp",
            interp_method
        ])
    if brain_mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(brain_mask)
        ])
    if ref_brain_mask is not None:
        cargs.extend([
            "--refmask",
            execution.input_file(ref_brain_mask)
        ])
    ret = VecregOutputs(
        root=execution.output_file("."),
        registered_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VECREG_METADATA",
    "VecregOutputs",
    "vecreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_WARP_DRIVE_METADATA = Metadata(
    id="94f1a8dd63cf363a9c26a553457737d194dec4be.boutiques",
    name="3dWarpDrive",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dWarpDriveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_warp_drive(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Warped dataset output"""
    output_summary: OutputPathType
    """Summary of calculations"""
    oned_output_file: OutputPathType
    """File with warping parameters"""
    matrix_output_file: OutputPathType
    """File with transformation matrices"""


def v_3d_warp_drive(
    base_dataset: InputPathType,
    prefix: str,
    dataset: InputPathType,
    bilinear_general: bool = False,
    quintic: bool = False,
    runner: Runner | None = None,
) -> V3dWarpDriveOutputs:
    """
    Warp a dataset to match another one (the base) using an affine transformation.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dWarpDrive.html
    
    Args:
        base_dataset: Load dataset as the base to which the input dataset will\
            be matched. This is a mandatory option.
        prefix: Sets the prefix of the output dataset. If 'NULL', no output\
            dataset is written.
        dataset: Input dataset.
        bilinear_general: 39 parameters (3 + 3x3 + 3x3x3). Not implemented and\
            will never be.
        quintic: Quintic interpolation method.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dWarpDriveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_WARP_DRIVE_METADATA)
    cargs = []
    cargs.append("3dWarpDrive")
    if bilinear_general:
        cargs.append("-bilinear_general")
    if quintic:
        cargs.append("-quintic")
    cargs.append("-base")
    cargs.extend([
        "-base",
        execution.input_file(base_dataset)
    ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.append("[TECHNICAL_OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3dWarpDriveOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + "+orig"),
        output_summary=execution.output_file("[SUMMARY]"),
        oned_output_file=execution.output_file("[1DFILE]"),
        matrix_output_file=execution.output_file("[1DMATRIX_SAVE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dWarpDriveOutputs",
    "V_3D_WARP_DRIVE_METADATA",
    "v_3d_warp_drive",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLROI_METADATA = Metadata(
    id="1a43cdbac23b3c8516c756db039e660882a2daba.boutiques",
    name="fslroi",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslroiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslroi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file containing the extracted ROI"""


def fslroi(
    infile: InputPathType,
    outfile: str,
    xmin: float | None = None,
    xsize: float | None = None,
    ymin: float | None = None,
    ysize: float | None = None,
    zmin: float | None = None,
    zsize: float | None = None,
    tmin: float | None = None,
    tsize: float | None = None,
    runner: Runner | None = None,
) -> FslroiOutputs:
    """
    Extracts a region of interest (ROI) from an image.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        infile: Input image file.
        outfile: Output image file.
        xmin: Minimum X coordinate for ROI (indexing starts at 0).
        xsize: Size of the ROI in X direction.
        ymin: Minimum Y coordinate for ROI (indexing starts at 0).
        ysize: Size of the ROI in Y direction.
        zmin: Minimum Z coordinate for ROI (indexing starts at 0).
        zsize: Size of the ROI in Z direction.
        tmin: Minimum T coordinate for ROI (indexing starts at 0).
        tsize: Size of the ROI in T direction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslroiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLROI_METADATA)
    cargs = []
    cargs.append("fslroi")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    if xmin is not None:
        cargs.append(str(xmin))
    if xsize is not None:
        cargs.append(str(xsize))
    if ymin is not None:
        cargs.append(str(ymin))
    if ysize is not None:
        cargs.append(str(ysize))
    if zmin is not None:
        cargs.append(str(zmin))
    if zsize is not None:
        cargs.append(str(zsize))
    if tmin is not None:
        cargs.append(str(tmin))
    if tsize is not None:
        cargs.append(str(tsize))
    ret = FslroiOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLROI_METADATA",
    "FslroiOutputs",
    "fslroi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLREORIENT2STD_METADATA = Metadata(
    id="98ad860c6642382747cdb3cc314cb5e47d03ab96.boutiques",
    name="fslreorient2std",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Fslreorient2stdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslreorient2std(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType | None
    """Reoriented output image (NIfTI format)"""
    matrix_output: OutputPathType
    """File to save the transformation matrix"""


def fslreorient2std(
    input_image: InputPathType,
    output_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> Fslreorient2stdOutputs:
    """
    A tool for reorienting an image to match the approximate orientation of standard
    template images (MNI152).
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils#fslreorient2std
    
    Args:
        input_image: Input image to be reoriented (NIfTI format, e.g.\
            img.nii.gz).
        output_image: Output image with the reoriented result (NIfTI format,\
            e.g. reoriented_img.nii.gz). If not provided, transformation matrix is\
            output to standard output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fslreorient2stdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLREORIENT2STD_METADATA)
    cargs = []
    cargs.append("fslreorient2std")
    cargs.append(execution.input_file(input_image))
    if output_image is not None:
        cargs.append(execution.input_file(output_image))
    cargs.append("[-m")
    cargs.append("MATRIX_FILE]")
    ret = Fslreorient2stdOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(pathlib.Path(output_image).name) if (output_image is not None) else None,
        matrix_output=execution.output_file("[MATRIX_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLREORIENT2STD_METADATA",
    "Fslreorient2stdOutputs",
    "fslreorient2std",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AVW2FSL_METADATA = Metadata(
    id="3110b2aae1aa53c6a38d7d7ec34da42b9d6614c8.boutiques",
    name="avw2fsl",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Avw2fslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `avw2fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dest: OutputPathType
    """Destination file or directory where the source is copied."""


def avw2fsl(
    runner: Runner | None = None,
) -> Avw2fslOutputs:
    """
    Processing script to copy files and directories.
    
    Author: GNU coreutils
    
    URL: http://www.gnu.org/software/coreutils/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Avw2fslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AVW2FSL_METADATA)
    cargs = []
    cargs.append("/bin/cp")
    cargs.append("[OPTIONS]")
    cargs.append("[SOURCE")
    cargs.append("DEST]")
    ret = Avw2fslOutputs(
        root=execution.output_file("."),
        output_dest=execution.output_file("[DEST]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AVW2FSL_METADATA",
    "Avw2fslOutputs",
    "avw2fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_REPLACE_STRUCTURE_METADATA = Metadata(
    id="7780641a00d19b64e740214a6e21ca25e3012574.boutiques",
    name="cifti-replace-structure",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiReplaceStructureVolumeAll:
    """
    replace the data in all volume components.
    """
    volume: InputPathType
    """the input volume"""
    opt_from_cropped: bool = False
    """the input is cropped to the size of the data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-all")
        cargs.append(execution.input_file(self.volume))
        if self.opt_from_cropped:
            cargs.append("-from-cropped")
        return cargs


@dataclasses.dataclass
class CiftiReplaceStructureLabel:
    """
    replace the data in a surface label component.
    """
    structure: str
    """the structure to replace the data of"""
    label: InputPathType
    """the input label file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-label")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.label))
        return cargs


@dataclasses.dataclass
class CiftiReplaceStructureMetric:
    """
    replace the data in a surface component.
    """
    structure: str
    """the structure to replace the data of"""
    metric: InputPathType
    """the input metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-metric")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.metric))
        return cargs


@dataclasses.dataclass
class CiftiReplaceStructureVolume:
    """
    replace the data in a volume component.
    """
    structure: str
    """the structure to replace the data of"""
    volume: InputPathType
    """the input volume"""
    opt_from_cropped: bool = False
    """the input is cropped to the size of the component"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.volume))
        if self.opt_from_cropped:
            cargs.append("-from-cropped")
        return cargs


class CiftiReplaceStructureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_replace_structure(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_replace_structure(
    cifti: str,
    direction: str,
    volume_all: CiftiReplaceStructureVolumeAll | None = None,
    opt_discard_unused_labels: bool = False,
    opt_label_collision_action: str | None = None,
    label: list[CiftiReplaceStructureLabel] | None = None,
    metric: list[CiftiReplaceStructureMetric] | None = None,
    volume: list[CiftiReplaceStructureVolume] | None = None,
    runner: Runner | None = None,
) -> CiftiReplaceStructureOutputs:
    """
    Replace data in a structure in a cifti file.
    
    This is a fairly low-level command, you probably want to use
    -cifti-create-dense-from-template instead.
    
    You must specify at least one of -metric, -label, -volume, or -volume-all
    for this command to do anything. Input volumes must line up with the output
    of -cifti-separate. For dtseries/dscalar, use COLUMN, and if your dconn
    matrix will be fully symmetric, COLUMN is more efficient. The -volume-all
    option must not be specified when using a -volume option. A -metric option
    must not be specified when using a -label option, and is not recommended on
    a label-type cifti file. For each <structure> argument, use one of the
    following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti: the cifti to modify.
        direction: which dimension to interpret as a single map, ROW or COLUMN.
        volume_all: replace the data in all volume components.
        opt_discard_unused_labels: when operating on a dlabel file, drop any\
            unused label keys from the label table.
        opt_label_collision_action: how to handle conflicts between label keys:\
            'ERROR', 'LEFT_SURFACE_FIRST', or 'LEGACY', default 'ERROR', use\
            'LEGACY' to match v1.4.2 and earlier.
        label: replace the data in a surface label component.
        metric: replace the data in a surface component.
        volume: replace the data in a volume component.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiReplaceStructureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_REPLACE_STRUCTURE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-replace-structure")
    cargs.append(cifti)
    cargs.append(direction)
    if volume_all is not None:
        cargs.extend(volume_all.run(execution))
    if opt_discard_unused_labels:
        cargs.append("-discard-unused-labels")
    if opt_label_collision_action is not None:
        cargs.extend([
            "-label-collision",
            opt_label_collision_action
        ])
    if label is not None:
        cargs.extend([a for c in [s.run(execution) for s in label] for a in c])
    if metric is not None:
        cargs.extend([a for c in [s.run(execution) for s in metric] for a in c])
    if volume is not None:
        cargs.extend([a for c in [s.run(execution) for s in volume] for a in c])
    ret = CiftiReplaceStructureOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_REPLACE_STRUCTURE_METADATA",
    "CiftiReplaceStructureLabel",
    "CiftiReplaceStructureMetric",
    "CiftiReplaceStructureOutputs",
    "CiftiReplaceStructureVolume",
    "CiftiReplaceStructureVolumeAll",
    "cifti_replace_structure",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_LENGTH_METADATA = Metadata(
    id="ce4d7fc98ecedfeee917036d8fd0ab85e22f1fd4.boutiques",
    name="border-length",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class BorderLengthOutputs(typing.NamedTuple):
    """
    Output object returned when calling `border_length(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def border_length(
    border: InputPathType,
    surface: InputPathType,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_separate_pieces: bool = False,
    opt_hide_border_name: bool = False,
    runner: Runner | None = None,
) -> BorderLengthOutputs:
    """
    Report length of borders.
    
    For each border, print its length along the surface, in mm. If a border has
    multiple parts, their lengths are summed before printing, unless
    -separate-pieces is specified.
    
    The -corrected-areas option is intended for when the length is not
    meaningfully measurable on individual surfaces, it is only an approximate
    correction for the reduction in structure of a group average surface.
    
    Author: Washington University School of Medicin
    
    Args:
        border: the input border file.
        surface: the surface to measure the borders on.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_separate_pieces: report lengths for multi-part borders as separate\
            numbers.
        opt_hide_border_name: don't print border name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderLengthOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_LENGTH_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-length")
    cargs.append(execution.input_file(border))
    cargs.append(execution.input_file(surface))
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    if opt_separate_pieces:
        cargs.append("-separate-pieces")
    if opt_hide_border_name:
        cargs.append("-hide-border-name")
    ret = BorderLengthOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_LENGTH_METADATA",
    "BorderLengthOutputs",
    "border_length",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SURF_SMOOTH_HEAT_07_EXAMPLES_METADATA = Metadata(
    id="8cd6363e3627678005d5a6020f811901335c73ef.boutiques",
    name="@SurfSmooth.HEAT_07.examples",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSurfSmoothHeat07ExamplesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__surf_smooth_heat_07_examples(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__surf_smooth_heat_07_examples(
    path_to_suma_demo: str,
    runner: Runner | None = None,
) -> VSurfSmoothHeat07ExamplesOutputs:
    """
    A script to illustrate controlled blurring of data on the surface.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@SurfSmooth.HEAT_07.examples.html
    
    Args:
        path_to_suma_demo: Path to SUMA demo directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSurfSmoothHeat07ExamplesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SURF_SMOOTH_HEAT_07_EXAMPLES_METADATA)
    cargs = []
    cargs.append("@SurfSmooth.HEAT_07.examples")
    cargs.append(path_to_suma_demo)
    ret = VSurfSmoothHeat07ExamplesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSurfSmoothHeat07ExamplesOutputs",
    "V__SURF_SMOOTH_HEAT_07_EXAMPLES_METADATA",
    "v__surf_smooth_heat_07_examples",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_COMPARE_AFFINE_METADATA = Metadata(
    id="7cfd722adbb4499de1713f354b48d813f3064d41.boutiques",
    name="3dCompareAffine",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dCompareAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_compare_affine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file containing comparison results of affine transformations"""


def v_3d_compare_affine(
    runner: Runner | None = None,
) -> V3dCompareAffineOutputs:
    """
    Compares two (or more) affine spatial transformations on a dataset and outputs
    measurements of their differences in spatial displacements.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dCompareAffine.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dCompareAffineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_COMPARE_AFFINE_METADATA)
    cargs = []
    cargs.append("3dCompareAffine")
    cargs.append("[OPTIONS]")
    ret = V3dCompareAffineOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("[OUTPUT_PREFIX]_comparison.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dCompareAffineOutputs",
    "V_3D_COMPARE_AFFINE_METADATA",
    "v_3d_compare_affine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TQUAL_METADATA = Metadata(
    id="051d67f70aafe97588824602cd1ef05d741f17f4.boutiques",
    name="3dTqual",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTqualOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tqual(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    time_series: OutputPathType
    """The 1D time series with the quality index for each sub-brick"""


def v_3d_tqual(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dTqualOutputs:
    """
    Computes a quality index for each sub-brick in a 3D+time dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTqual.html
    
    Args:
        dataset: Input 3D+time dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTqualOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TQUAL_METADATA)
    cargs = []
    cargs.append("3dTqual")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3dTqualOutputs(
        root=execution.output_file("."),
        time_series=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTqualOutputs",
    "V_3D_TQUAL_METADATA",
    "v_3d_tqual",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RETINO_PHASE_METADATA = Metadata(
    id="3fcf125ca005c8d78e8e888d9df0d963f73cc8fb.boutiques",
    name="3dRetinoPhase",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRetinoPhaseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_retino_phase(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    ecc_plus: OutputPathType
    """Output file for positive (expanding) eccentricity"""
    ecc_minus: OutputPathType
    """Output file for negative (contracting) eccentricity"""
    pol_plus: OutputPathType
    """Output file for clockwise polar angle mapping"""
    pol_minus: OutputPathType
    """Output file for counterclockwise polar angle mapping"""


def v_3d_retino_phase(
    prefix: str,
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dRetinoPhaseOutputs:
    """
    Process time series from retinotopy stimuli to create phase datasets and visual
    field angle datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dRetinoPhase.html
    
    Args:
        prefix: Prefix of output datasets.
        dataset: Time series from a retinotopy stimulus.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRetinoPhaseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RETINO_PHASE_METADATA)
    cargs = []
    cargs.append("3dRetinoPhase")
    cargs.append(prefix)
    cargs.append(execution.input_file(dataset))
    cargs.append("[OPTIONS]")
    ret = V3dRetinoPhaseOutputs(
        root=execution.output_file("."),
        ecc_plus=execution.output_file("[PREFIX].ecc+"),
        ecc_minus=execution.output_file("[PREFIX].ecc-"),
        pol_plus=execution.output_file("[PREFIX].pol+"),
        pol_minus=execution.output_file("[PREFIX].pol-"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRetinoPhaseOutputs",
    "V_3D_RETINO_PHASE_METADATA",
    "v_3d_retino_phase",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PYTHON_MODULE_TEST_PY_METADATA = Metadata(
    id="614d501177ac8886b18aafb60fea6cd60289ed17.boutiques",
    name="python_module_test.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PythonModuleTestPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `python_module_test_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def python_module_test_py(
    full_test: bool = False,
    platform_info: bool = False,
    python_ver: bool = False,
    test_defaults: bool = False,
    test_modules: list[str] | None = None,
    verbose: float | None = None,
    help_: bool = False,
    hist: bool = False,
    show_valid_opts: bool = False,
    ver: bool = False,
    runner: Runner | None = None,
) -> PythonModuleTestPyOutputs:
    """
    Test the loading of Python modules, specifically designed to ensure
    compatibility with AFNI software.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/python_module_test.py.html
    
    Args:
        full_test: Perform all of the standard tests.
        platform_info: Display system information, including OS and version\
            along with the CPU type.
        python_ver: Display the version of Python in use.
        test_defaults: Test the default module list used by AFNI programs.
        test_modules: Test the specified list of modules.
        verbose: Specify a verbose level.
        help_: Display the help message.
        hist: Display the modification history.
        show_valid_opts: Display all valid options in a short format.
        ver: Display the version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PythonModuleTestPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PYTHON_MODULE_TEST_PY_METADATA)
    cargs = []
    cargs.append("python_module_test.py")
    if full_test:
        cargs.append("-full_test")
    if platform_info:
        cargs.append("-platform_info")
    if python_ver:
        cargs.append("-python_ver")
    if test_defaults:
        cargs.append("-test_defaults")
    if test_modules is not None:
        cargs.extend([
            "-test_modules",
            *test_modules
        ])
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if show_valid_opts:
        cargs.append("-show_valid_opts")
    if ver:
        cargs.append("-ver")
    ret = PythonModuleTestPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PYTHON_MODULE_TEST_PY_METADATA",
    "PythonModuleTestPyOutputs",
    "python_module_test_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NIFTI_INFORMATION_METADATA = Metadata(
    id="3670afb5bf0423fff751f00b9b31c3bc3363791f.boutiques",
    name="nifti-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class NiftiInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nifti_information(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def nifti_information(
    nifti_file: str,
    opt_print_header: bool = False,
    opt_allow_truncated: bool = False,
    opt_print_matrix: bool = False,
    opt_print_xml: bool = False,
    opt_version_version: str | None = None,
    runner: Runner | None = None,
) -> NiftiInformationOutputs:
    """
    Display information about a nifti/cifti file.
    
    You must specify at least one -print-* option.
    
    Author: Washington University School of Medicin
    
    Args:
        nifti_file: the nifti/cifti file to examine.
        opt_print_header: display the header contents.
        opt_allow_truncated: print the header even if the data is truncated.
        opt_print_matrix: output the values in the matrix (cifti only).
        opt_print_xml: print the cifti XML (cifti only).
        opt_version_version: convert the XML to a specific CIFTI version\
            (default is the file's cifti version): the CIFTI version to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NiftiInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NIFTI_INFORMATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-nifti-information")
    cargs.append(nifti_file)
    if opt_print_header:
        cargs.append("-print-header")
    if opt_allow_truncated:
        cargs.append("-allow-truncated")
    if opt_print_matrix:
        cargs.append("-print-matrix")
    if opt_print_xml:
        cargs.append("-print-xml")
    if opt_version_version is not None:
        cargs.extend([
            "-version",
            opt_version_version
        ])
    ret = NiftiInformationOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NIFTI_INFORMATION_METADATA",
    "NiftiInformationOutputs",
    "nifti_information",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_RESAMPLE_METADATA = Metadata(
    id="b1912269948fd60cbfa4b6bac064915aca2e5a13.boutiques",
    name="label-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class LabelResampleAreaSurfs:
    """
    specify surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant anatomical surface with <current-sphere> mesh"""
    new_area: InputPathType
    """a relevant anatomical surface with <new-sphere> mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class LabelResampleAreaMetrics:
    """
    specify vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for <current-sphere> mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for <new-sphere> mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


class LabelResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""
    roi_out: OutputPathType
    """the output roi as a metric"""


def label_resample(
    label_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    label_out: str,
    roi_out: str,
    area_surfs: LabelResampleAreaSurfs | None = None,
    area_metrics: LabelResampleAreaMetrics | None = None,
    opt_current_roi_roi_metric: InputPathType | None = None,
    opt_valid_roi_out: bool = False,
    opt_largest: bool = False,
    opt_bypass_sphere_check: bool = False,
    runner: Runner | None = None,
) -> LabelResampleOutputs:
    """
    Resample a label file to a different mesh.
    
    Resamples a label file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified.
    
    The ADAP_BARY_AREA method is recommended for label data, because it should
    be better at resolving vertices that are near multiple labels, or in case of
    downsampling. Midthickness surfaces are recommended for the vertex areas for
    most data.
    
    The -largest option results in nearest vertex behavior when used with
    BARYCENTRIC, as it uses the value of the source vertex that has the largest
    weight.
    
    When -largest is not specified, the vertex weights are summed according to
    which label they correspond to, and the label with the largest sum is used.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Washington University School of Medicin
    
    Args:
        label_in: the label file to resample.
        current_sphere: a sphere surface with the mesh that the label file is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        label_out: the output label file.
        roi_out: the output roi as a metric.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_current_roi_roi_metric: use an input roi on the current mesh to\
            exclude non-data vertices: the roi, as a metric file.
        opt_valid_roi_out: output the ROI of vertices that got data from valid\
            source vertices.
        opt_largest: use only the label of the vertex with the largest weight.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-resample")
    cargs.append(execution.input_file(label_in))
    cargs.append(execution.input_file(current_sphere))
    cargs.append(execution.input_file(new_sphere))
    cargs.append(method)
    cargs.append(label_out)
    if area_surfs is not None:
        cargs.extend(area_surfs.run(execution))
    if area_metrics is not None:
        cargs.extend(area_metrics.run(execution))
    if opt_current_roi_roi_metric is not None:
        cargs.extend([
            "-current-roi",
            execution.input_file(opt_current_roi_roi_metric)
        ])
    if opt_valid_roi_out:
        cargs.append("-valid-roi-out")
    cargs.append(roi_out)
    if opt_largest:
        cargs.append("-largest")
    if opt_bypass_sphere_check:
        cargs.append("-bypass-sphere-check")
    ret = LabelResampleOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(label_out),
        roi_out=execution.output_file(roi_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_RESAMPLE_METADATA",
    "LabelResampleAreaMetrics",
    "LabelResampleAreaSurfs",
    "LabelResampleOutputs",
    "label_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_2DCAT_METADATA = Metadata(
    id="56683a58e70bc4cb5e35cd2aa07ec487e9a471e1.boutiques",
    name="2dcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2dcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_2dcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The main output image matrix file."""
    output_1_d: OutputPathType
    """A 1D file containing the average of RGB values, if the prefix ends with
    .1D."""


def v_2dcat(
    filenames: list[InputPathType],
    runner: Runner | None = None,
) -> V2dcatOutputs:
    """
    Puts a set of images into an image matrix montage of NX by NY images.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/2dcat.html
    
    Args:
        filenames: List of input image files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2dcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_2DCAT_METADATA)
    cargs = []
    cargs.append("2dcat")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in filenames])
    ret = V2dcatOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file("[PREFIX].ppm"),
        output_1_d=execution.output_file("[PREFIX].1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2dcatOutputs",
    "V_2DCAT_METADATA",
    "v_2dcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_FIRST_ALL_METADATA = Metadata(
    id="3ff68b6fa9e7b0f99ef830ac8b11ae006c1452c2.boutiques",
    name="run_first_all",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class RunFirstAllOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_first_all(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """Output image file"""


def run_first_all(
    input_image: InputPathType,
    output_image: str,
    method: typing.Literal["auto", "fast", "none"] | None = None,
    brainextract_flag: bool = False,
    structure: str | None = None,
    affine_matrix: InputPathType | None = None,
    threestage_flag: bool = False,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> RunFirstAllOutputs:
    """
    FIRST - FMRIB's Integrated Registration and Segmentation Tool for subcortical
    brain structures.
    
    Author: FMRIB Software Library (FSL)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FIRST
    
    Args:
        input_image: Input image file.
        output_image: Output image file.
        method: Method for brain extraction (auto, fast, none or a numerical\
            threshold value).
        brainextract_flag: Input is already brain extracted.
        structure: Run only on one specified structure (e.g. L_Hipp) or a comma\
            separated list (no spaces).
        affine_matrix: Use affine matrix (do not re-run registration).
        threestage_flag: Use 3-stage affine registration (only currently for\
            hippocampus).
        debug_flag: Do not cleanup image output files (useful for debugging).
        verbose_flag: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunFirstAllOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_FIRST_ALL_METADATA)
    cargs = []
    cargs.append("run_first_all")
    if method is not None:
        cargs.extend([
            "-m",
            method
        ])
    if brainextract_flag:
        cargs.append("-b")
    if structure is not None:
        cargs.extend([
            "-s",
            structure
        ])
    if affine_matrix is not None:
        cargs.extend([
            "-a",
            execution.input_file(affine_matrix)
        ])
    if threestage_flag:
        cargs.append("-3")
    if debug_flag:
        cargs.append("-d")
    if verbose_flag:
        cargs.append("-v")
    cargs.append("-i")
    cargs.append(execution.input_file(input_image))
    cargs.append("-o")
    cargs.append(output_image)
    ret = RunFirstAllOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_FIRST_ALL_METADATA",
    "RunFirstAllOutputs",
    "run_first_all",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DTTEST___METADATA = Metadata(
    id="7677b966a0ac3126ffb377f3e909b0bf5a1cbd37.boutiques",
    name="3dttest++",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dttestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dttest__(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Main output dataset"""
    residuals: OutputPathType
    """Output residuals dataset"""


def v_3dttest__(
    set_b: list[str] | None = None,
    runner: Runner | None = None,
) -> V3dttestOutputs:
    """
    Gosset (Student) t-test of sets of 3D datasets in AFNI.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dttest++.html
    
    Args:
        set_b: Set B in short form, e.g., 'x+tlrc[3]' y+tlrc[3] ...'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dttestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DTTEST___METADATA)
    cargs = []
    cargs.append("3dttest++")
    if set_b is not None:
        cargs.extend([
            "-setB",
            *set_b
        ])
    cargs.append("[OPTIONS]")
    cargs.append("[MASK_OPTIONS]")
    cargs.append("[ETAC_OPTIONS]")
    cargs.append("[OTHER_OPTIONS]")
    ret = V3dttestOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file("[PREFIX].nii.gz"),
        residuals=execution.output_file("[PREFIX_RESID].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dttestOutputs",
    "V_3DTTEST___METADATA",
    "v_3dttest__",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__NO_POUND_METADATA = Metadata(
    id="e8966af56389c1235a2a32ff16269adde3aec8d4.boutiques",
    name="@NoPound",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VNoPoundOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__no_pound(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__no_pound(
    afni_files: list[str],
    runner: Runner | None = None,
) -> VNoPoundOutputs:
    """
    Replaces all # characters in AFNI filenames with a -.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@NoPound.html
    
    Args:
        afni_files: List of AFNI files where # characters should be replaced\
            with -.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VNoPoundOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__NO_POUND_METADATA)
    cargs = []
    cargs.append("@NoPound")
    cargs.extend(afni_files)
    ret = VNoPoundOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VNoPoundOutputs",
    "V__NO_POUND_METADATA",
    "v__no_pound",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SCALE_VOLUME_METADATA = Metadata(
    id="703709f4d288b4dc526dfb3555e60357899a9633.boutiques",
    name="@ScaleVolume",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VScaleVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__scale_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output scaled dataset"""


def v__scale_volume(
    runner: Runner | None = None,
) -> VScaleVolumeOutputs:
    """
    A tool to scale the volume of datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ScaleVolume.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VScaleVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SCALE_VOLUME_METADATA)
    cargs = []
    cargs.append("@ScaleVolume")
    cargs.append("<-input")
    cargs.append("DSET>")
    cargs.append("<-prefix")
    cargs.append("PREFIX>")
    cargs.append("[-perc_clip")
    cargs.append("P0")
    cargs.append("P1]")
    cargs.append("[-val_clip")
    cargs.append("V0")
    cargs.append("V1]")
    cargs.append("[-scale_by_mean]")
    cargs.append("[-scale_by_median]")
    cargs.append("[-norm]")
    cargs.append("[-mask")
    cargs.append("MSET]")
    ret = VScaleVolumeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("<-prefix PREFIX>_scaled"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VScaleVolumeOutputs",
    "V__SCALE_VOLUME_METADATA",
    "v__scale_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AUTOMASK_METADATA = Metadata(
    id="4c4dea39415d0dfa3511b858d1bcbcf03ec341e6.boutiques",
    name="3dAutomask",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAutomaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_automask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    brain_file: OutputPathType
    """Output file from 3dautomask."""
    out_file: OutputPathType
    """Output image file name."""
    brain_file_: OutputPathType
    """Brain file (skull stripped)."""
    out_file_: OutputPathType
    """Mask file."""


def v_3d_automask(
    in_file: InputPathType,
    clfrac: float | None = None,
    dilate: int | None = None,
    erode: int | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    runner: Runner | None = None,
) -> V3dAutomaskOutputs:
    """
    Create a brain-only mask of the image using AFNI 3dAutomask command.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAutomask.html
    
    Args:
        in_file: Input file to 3dautomask.
        clfrac: Sets the clip level fraction (must be 0.1-0.9). a small value\
            will tend to make the mask larger [default = 0.5].
        dilate: Dilate the mask outwards.
        erode: Erode the mask inwards.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAutomaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AUTOMASK_METADATA)
    cargs = []
    cargs.append("3dAutomask")
    cargs.append(execution.input_file(in_file))
    cargs.append("[BRAIN_FILE]")
    if clfrac is not None:
        cargs.extend([
            "-clfrac",
            str(clfrac)
        ])
    if dilate is not None:
        cargs.extend([
            "-dilate",
            str(dilate)
        ])
    if erode is not None:
        cargs.extend([
            "-erode",
            str(erode)
        ])
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    ret = V3dAutomaskOutputs(
        root=execution.output_file("."),
        brain_file=execution.output_file(pathlib.Path(in_file).name + "_masked"),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_mask"),
        brain_file_=execution.output_file("brain_file"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAutomaskOutputs",
    "V_3D_AUTOMASK_METADATA",
    "v_3d_automask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NWARP_FUNCS_METADATA = Metadata(
    id="902fe0ee182e6718b00f67b363f21031d064f103.boutiques",
    name="3dNwarpFuncs",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNwarpFuncsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_nwarp_funcs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The output dataset with the computed functions."""


def v_3d_nwarp_funcs(
    input_warp: InputPathType,
    output_prefix: str,
    bulk_flag: bool = False,
    shear_flag: bool = False,
    vorticity_flag: bool = False,
    all_flag: bool = False,
    runner: Runner | None = None,
) -> V3dNwarpFuncsOutputs:
    """
    Compute functions of 3D warp displacements, such as bulk volume change, shear
    energy, and vorticity energy.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dNwarpFuncs.html
    
    Args:
        input_warp: 'www' is the name of the 3D warp dataset (mandatory\
            option).
        output_prefix: 'ppp' is the name of the new output dataset.
        bulk_flag: Compute the (fractional) bulk volume change (Jacobian\
            determinant minus 1).
        shear_flag: Compute the shear energy.
        vorticity_flag: Compute the vorticity energy.
        all_flag: Compute all 3 functions: bulk, shear, and vorticity.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNwarpFuncsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NWARP_FUNCS_METADATA)
    cargs = []
    cargs.append("3dNwarpFuncs")
    cargs.extend([
        "-nwarp",
        execution.input_file(input_warp)
    ])
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if bulk_flag:
        cargs.append("-bulk")
    if shear_flag:
        cargs.append("-shear")
    if vorticity_flag:
        cargs.append("-vorticity")
    if all_flag:
        cargs.append("-all")
    ret = V3dNwarpFuncsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix + "_output.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNwarpFuncsOutputs",
    "V_3D_NWARP_FUNCS_METADATA",
    "v_3d_nwarp_funcs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NEW_INVWARP_METADATA = Metadata(
    id="99dbbd756c597bc63d56f925f716ab35947148f0.boutiques",
    name="new_invwarp",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class NewInvwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `new_invwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output inverse warped image"""


def new_invwarp(
    warp_file: InputPathType,
    out_file: str,
    ref_file: InputPathType,
    relative_warp_flag: bool = False,
    absolute_warp_flag: bool = False,
    no_constraint_flag: bool = False,
    min_jacobian: float | None = 0.01,
    max_jacobian: float | None = 100.0,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> NewInvwarpOutputs:
    """
    Tool for inverting warp fields in FSL.
    
    Author: University of Oxford (Jesper Andersson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FNIRT/UserGuide#Using_invwarp
    
    Args:
        warp_file: Filename for warp/shiftmap transform (volume).
        out_file: Filename for output (inverse warped) image.
        ref_file: Filename for new reference image, i.e., what was originally\
            the input image (determines inverse warpvol's FOV and pixdims).
        relative_warp_flag: Use relative warp convention: x' = x + w(x).
        absolute_warp_flag: Use absolute warp convention (default): x' = w(x).
        no_constraint_flag: Do not apply the Jacobian constraint.
        min_jacobian: Minimum acceptable Jacobian value for constraint (default\
            0.01).
        max_jacobian: Maximum acceptable Jacobian value for constraint (default\
            100.0).
        debug_flag: Turn on debugging output.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NewInvwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NEW_INVWARP_METADATA)
    cargs = []
    cargs.append("invwarp")
    cargs.append("--warp")
    cargs.extend([
        "--warp",
        execution.input_file(warp_file)
    ])
    cargs.append("--out")
    cargs.extend([
        "--out",
        out_file
    ])
    cargs.append("--ref")
    cargs.extend([
        "--ref",
        execution.input_file(ref_file)
    ])
    if relative_warp_flag:
        cargs.append("--rel")
    if absolute_warp_flag:
        cargs.append("--abs")
    if no_constraint_flag:
        cargs.append("--noconstraint")
    if min_jacobian is not None:
        cargs.extend([
            "--jmin",
            str(min_jacobian)
        ])
    if max_jacobian is not None:
        cargs.extend([
            "--jmax",
            str(max_jacobian)
        ])
    if debug_flag:
        cargs.append("--debug")
    if verbose_flag:
        cargs.append("--verbose")
    ret = NewInvwarpOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(out_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NEW_INVWARP_METADATA",
    "NewInvwarpOutputs",
    "new_invwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CLUST_COUNT_METADATA = Metadata(
    id="0c61eab7e3dd1ba960105baacb7691a7039c8be4.boutiques",
    name="3dClustCount",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dClustCountOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_clust_count(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    clustcount_niml: OutputPathType
    """Summed results file in NIML format."""
    clustcount_1_d: OutputPathType
    """Summed results file in 1D format (when '-final' is used)."""
    final_clustcount_niml: OutputPathType
    """Summed results file in NIML format (when '-final' is used)."""


def v_3d_clust_count(
    runner: Runner | None = None,
) -> V3dClustCountOutputs:
    """
    This program takes as input 1 or more datasets, thresholds them at various
    levels, and counts up the number of clusters of various sizes.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dClustCount.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dClustCountOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CLUST_COUNT_METADATA)
    cargs = []
    cargs.append("3dClustCount")
    cargs.append("[OPTIONS]")
    cargs.append("DATASETS")
    ret = V3dClustCountOutputs(
        root=execution.output_file("."),
        clustcount_niml=execution.output_file("[PREFIX].clustcount.niml"),
        clustcount_1_d=execution.output_file("[PREFIX].1D"),
        final_clustcount_niml=execution.output_file("[PREFIX].niml"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dClustCountOutputs",
    "V_3D_CLUST_COUNT_METADATA",
    "v_3d_clust_count",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_RESAMPLE_METADATA = Metadata(
    id="839457011a551747f0c4b7746c3af5e6f7e81680.boutiques",
    name="cifti-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiResampleWeighted:
    """
    use weighted dilation (default).
    """
    opt_exponent_exponent: float | None = None
    """specify exponent in weighting function: exponent 'n' to use in (1 /
    (distance ^ n)) as the weighting function (default 7)"""
    opt_legacy_cutoff: bool = False
    """use v1.3.2 logic for the kernel cutoff"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-weighted")
        if self.opt_exponent_exponent is not None:
            cargs.extend([
                "-exponent",
                str(self.opt_exponent_exponent)
            ])
        if self.opt_legacy_cutoff:
            cargs.append("-legacy-cutoff")
        return cargs


@dataclasses.dataclass
class CiftiResampleVolumePredilate:
    """
    dilate the volume components before resampling.
    """
    dilate_mm: float
    """distance, in mm, to dilate"""
    opt_nearest: bool = False
    """use nearest value dilation"""
    weighted: CiftiResampleWeighted | None = None
    """use weighted dilation (default)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-predilate")
        cargs.append(str(self.dilate_mm))
        if self.opt_nearest:
            cargs.append("-nearest")
        if self.weighted is not None:
            cargs.extend(self.weighted.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleWeighted_:
    """
    use weighted dilation (default for non-label data).
    """
    opt_exponent_exponent: float | None = None
    """specify exponent in weighting function: exponent 'n' to use in (area /
    (distance ^ n)) as the weighting function (default 6)"""
    opt_legacy_cutoff: bool = False
    """use v1.3.2 logic for the kernel cutoff"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-weighted")
        if self.opt_exponent_exponent is not None:
            cargs.extend([
                "-exponent",
                str(self.opt_exponent_exponent)
            ])
        if self.opt_legacy_cutoff:
            cargs.append("-legacy-cutoff")
        return cargs


@dataclasses.dataclass
class CiftiResampleSurfacePostdilate:
    """
    dilate the surface components after resampling.
    """
    dilate_mm: float
    """distance, in mm, to dilate"""
    opt_nearest: bool = False
    """use nearest value dilation"""
    opt_linear: bool = False
    """use linear dilation"""
    weighted: CiftiResampleWeighted_ | None = None
    """use weighted dilation (default for non-label data)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-surface-postdilate")
        cargs.append(str(self.dilate_mm))
        if self.opt_nearest:
            cargs.append("-nearest")
        if self.opt_linear:
            cargs.append("-linear")
        if self.weighted is not None:
            cargs.extend(self.weighted.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleFlirt:
    """
    MUST be used if affine is a flirt affine.
    """
    source_volume: str
    """the source volume used when generating the affine"""
    target_volume: str
    """the target volume used when generating the affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-flirt")
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


@dataclasses.dataclass
class CiftiResampleAffine:
    """
    use an affine transformation on the volume components.
    """
    affine_file: str
    """the affine file to use"""
    flirt: CiftiResampleFlirt | None = None
    """MUST be used if affine is a flirt affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-affine")
        cargs.append(self.affine_file)
        if self.flirt is not None:
            cargs.extend(self.flirt.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleWarpfield:
    """
    use a warpfield on the volume components.
    """
    warpfield: str
    """the warpfield to use"""
    opt_fnirt_source_volume: str | None = None
    """MUST be used if using a fnirt warpfield: the source volume used when
    generating the warpfield"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-warpfield")
        cargs.append(self.warpfield)
        if self.opt_fnirt_source_volume is not None:
            cargs.extend([
                "-fnirt",
                self.opt_fnirt_source_volume
            ])
        return cargs


@dataclasses.dataclass
class CiftiResampleLeftAreaSurfs:
    """
    specify left surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant left anatomical surface with current mesh"""
    new_area: InputPathType
    """a relevant left anatomical surface with new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleLeftAreaMetrics:
    """
    specify left vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for the current mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for the new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleLeftSpheres:
    """
    specify spheres for left surface resampling.
    """
    current_sphere: InputPathType
    """a sphere with the same mesh as the current left surface"""
    new_sphere: InputPathType
    """a sphere with the new left mesh that is in register with the current
    sphere"""
    left_area_surfs: CiftiResampleLeftAreaSurfs | None = None
    """specify left surfaces to do vertex area correction based on"""
    left_area_metrics: CiftiResampleLeftAreaMetrics | None = None
    """specify left vertex area metrics to do area correction based on"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-spheres")
        cargs.append(execution.input_file(self.current_sphere))
        cargs.append(execution.input_file(self.new_sphere))
        if self.left_area_surfs is not None:
            cargs.extend(self.left_area_surfs.run(execution))
        if self.left_area_metrics is not None:
            cargs.extend(self.left_area_metrics.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleRightAreaSurfs:
    """
    specify right surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant right anatomical surface with current mesh"""
    new_area: InputPathType
    """a relevant right anatomical surface with new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleRightAreaMetrics:
    """
    specify right vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for the current mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for the new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleRightSpheres:
    """
    specify spheres for right surface resampling.
    """
    current_sphere: InputPathType
    """a sphere with the same mesh as the current right surface"""
    new_sphere: InputPathType
    """a sphere with the new right mesh that is in register with the current
    sphere"""
    right_area_surfs: CiftiResampleRightAreaSurfs | None = None
    """specify right surfaces to do vertex area correction based on"""
    right_area_metrics: CiftiResampleRightAreaMetrics | None = None
    """specify right vertex area metrics to do area correction based on"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-spheres")
        cargs.append(execution.input_file(self.current_sphere))
        cargs.append(execution.input_file(self.new_sphere))
        if self.right_area_surfs is not None:
            cargs.extend(self.right_area_surfs.run(execution))
        if self.right_area_metrics is not None:
            cargs.extend(self.right_area_metrics.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleCerebellumAreaSurfs:
    """
    specify cerebellum surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant cerebellum anatomical surface with current mesh"""
    new_area: InputPathType
    """a relevant cerebellum anatomical surface with new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleCerebellumAreaMetrics:
    """
    specify cerebellum vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for the current mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for the new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleCerebellumSpheres:
    """
    specify spheres for cerebellum surface resampling.
    """
    current_sphere: InputPathType
    """a sphere with the same mesh as the current cerebellum surface"""
    new_sphere: InputPathType
    """a sphere with the new cerebellum mesh that is in register with the
    current sphere"""
    cerebellum_area_surfs: CiftiResampleCerebellumAreaSurfs | None = None
    """specify cerebellum surfaces to do vertex area correction based on"""
    cerebellum_area_metrics: CiftiResampleCerebellumAreaMetrics | None = None
    """specify cerebellum vertex area metrics to do area correction based on"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-spheres")
        cargs.append(execution.input_file(self.current_sphere))
        cargs.append(execution.input_file(self.new_sphere))
        if self.cerebellum_area_surfs is not None:
            cargs.extend(self.cerebellum_area_surfs.run(execution))
        if self.cerebellum_area_metrics is not None:
            cargs.extend(self.cerebellum_area_metrics.run(execution))
        return cargs


class CiftiResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_resample(
    cifti_in: InputPathType,
    direction: str,
    cifti_template: InputPathType,
    template_direction: str,
    surface_method: str,
    volume_method: str,
    cifti_out: str,
    opt_surface_largest: bool = False,
    volume_predilate: CiftiResampleVolumePredilate | None = None,
    surface_postdilate: CiftiResampleSurfacePostdilate | None = None,
    affine: CiftiResampleAffine | None = None,
    warpfield: CiftiResampleWarpfield | None = None,
    left_spheres: CiftiResampleLeftSpheres | None = None,
    right_spheres: CiftiResampleRightSpheres | None = None,
    cerebellum_spheres: CiftiResampleCerebellumSpheres | None = None,
    runner: Runner | None = None,
) -> CiftiResampleOutputs:
    """
    Resample a cifti file to a new cifti space.
    
    Resample cifti data to a different brainordinate space. Use COLUMN for the
    direction to resample dscalar, dlabel, or dtseries. Resampling both
    dimensions of a dconn requires running this command twice, once with COLUMN
    and once with ROW. If you are resampling a dconn and your machine has a
    large amount of memory, you might consider using
    -cifti-resample-dconn-memory to avoid writing and rereading an intermediate
    file. The <template-direction> argument should usually be COLUMN, as
    dtseries, dscalar, and dlabel all have brainordinates on that direction. If
    spheres are not specified for a surface structure which exists in the cifti
    files, its data is copied without resampling or dilation. Dilation is done
    with the 'nearest' method, and is done on <new-sphere> for surface data.
    Volume components are padded before dilation so that dilation doesn't run
    into the edge of the component bounding box. If neither -affine nor
    -warpfield are specified, the identity transform is assumed for the volume
    data.
    
    The recommended resampling methods are ADAP_BARY_AREA and CUBIC (cubic
    spline), except for label data which should use ADAP_BARY_AREA and
    ENCLOSING_VOXEL. Using ADAP_BARY_AREA requires specifying an area option to
    each used -*-spheres option.
    
    The <volume-method> argument must be one of the following:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR
    
    The <surface-method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the cifti file to resample.
        direction: the direction of the input that should be resampled, ROW or\
            COLUMN.
        cifti_template: a cifti file containing the cifti space to resample to.
        template_direction: the direction of the template to use as the\
            resampling space, ROW or COLUMN.
        surface_method: specify a surface resampling method.
        volume_method: specify a volume interpolation method.
        cifti_out: the output cifti file.
        opt_surface_largest: use largest weight instead of weighted average or\
            popularity when doing surface resampling.
        volume_predilate: dilate the volume components before resampling.
        surface_postdilate: dilate the surface components after resampling.
        affine: use an affine transformation on the volume components.
        warpfield: use a warpfield on the volume components.
        left_spheres: specify spheres for left surface resampling.
        right_spheres: specify spheres for right surface resampling.
        cerebellum_spheres: specify spheres for cerebellum surface resampling.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-resample")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(direction)
    cargs.append(execution.input_file(cifti_template))
    cargs.append(template_direction)
    cargs.append(surface_method)
    cargs.append(volume_method)
    cargs.append(cifti_out)
    if opt_surface_largest:
        cargs.append("-surface-largest")
    if volume_predilate is not None:
        cargs.extend(volume_predilate.run(execution))
    if surface_postdilate is not None:
        cargs.extend(surface_postdilate.run(execution))
    if affine is not None:
        cargs.extend(affine.run(execution))
    if warpfield is not None:
        cargs.extend(warpfield.run(execution))
    if left_spheres is not None:
        cargs.extend(left_spheres.run(execution))
    if right_spheres is not None:
        cargs.extend(right_spheres.run(execution))
    if cerebellum_spheres is not None:
        cargs.extend(cerebellum_spheres.run(execution))
    ret = CiftiResampleOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_RESAMPLE_METADATA",
    "CiftiResampleAffine",
    "CiftiResampleCerebellumAreaMetrics",
    "CiftiResampleCerebellumAreaSurfs",
    "CiftiResampleCerebellumSpheres",
    "CiftiResampleFlirt",
    "CiftiResampleLeftAreaMetrics",
    "CiftiResampleLeftAreaSurfs",
    "CiftiResampleLeftSpheres",
    "CiftiResampleOutputs",
    "CiftiResampleRightAreaMetrics",
    "CiftiResampleRightAreaSurfs",
    "CiftiResampleRightSpheres",
    "CiftiResampleSurfacePostdilate",
    "CiftiResampleVolumePredilate",
    "CiftiResampleWarpfield",
    "CiftiResampleWeighted",
    "CiftiResampleWeighted_",
    "cifti_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MVM_METADATA = Metadata(
    id="f9b6c1adae03ff8547ed0f7bd736d82969fa192b.boutiques",
    name="3dMVM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMvmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mvm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_head: OutputPathType
    """Output HEAD file in AFNI format"""
    outfile_brik: OutputPathType
    """Output BRIK file in AFNI format"""


def v_3d_mvm(
    prefix: str,
    bs_vars: str,
    data_table: str,
    dbg_args: str | None = None,
    jobs: int | None = None,
    mask: InputPathType | None = None,
    ws_vars: str | None = None,
    q_vars: str | None = None,
    q_var_centers: str | None = None,
    num_glt: int | None = None,
    glt_label: str | None = None,
    glt_code: str | None = None,
    num_glf: int | None = None,
    glf_label: str | None = None,
    glf_code: str | None = None,
    runner: Runner | None = None,
) -> V3dMvmOutputs:
    """
    AFNI Group Analysis Program with Multi-Variate Modeling Approach.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMVM.html
    
    Args:
        prefix: Output file name prefix.
        bs_vars: Formula for between-subjects variables.
        data_table: Data table for analysis.
        dbg_args: Enable R to save parameters in a file for debugging.
        jobs: Number of jobs for parallel processing.
        mask: Only process voxels inside this mask.
        ws_vars: Formula for within-subjects variables.
        q_vars: Comma-separated list of quantitative variables (covariates).
        q_var_centers: Comma-separated centering values for quantitative\
            variables.
        num_glt: Number of general linear t-tests (GLTs).
        glt_label: Label for each general linear t-test (GLT).
        glt_code: Coding for each general linear t-test (GLT).
        num_glf: Number of general linear F-tests (GLFs).
        glf_label: Label for each general linear F-test (GLF).
        glf_code: Coding for each general linear F-test (GLF).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMvmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MVM_METADATA)
    cargs = []
    cargs.append("3dMVM")
    if dbg_args is not None:
        cargs.append(dbg_args)
    cargs.append("-prefix")
    cargs.append(prefix)
    cargs.append("-jobs")
    if jobs is not None:
        cargs.append(str(jobs))
    cargs.append("-mask")
    if mask is not None:
        cargs.append(execution.input_file(mask))
    cargs.append("-bsVars")
    cargs.append(bs_vars)
    cargs.append("-wsVars")
    if ws_vars is not None:
        cargs.append(ws_vars)
    cargs.append("-qVars")
    if q_vars is not None:
        cargs.append(q_vars)
    cargs.append("-qVarCenters")
    if q_var_centers is not None:
        cargs.append(q_var_centers)
    cargs.append("-num_glt")
    if num_glt is not None:
        cargs.append(str(num_glt))
    cargs.append("-gltLabel")
    if glt_label is not None:
        cargs.append(glt_label)
    cargs.append("-gltCode")
    if glt_code is not None:
        cargs.append(glt_code)
    cargs.append("-num_glf")
    if num_glf is not None:
        cargs.append(str(num_glf))
    cargs.append("-glfLabel")
    if glf_label is not None:
        cargs.append(glf_label)
    cargs.append("-glfCode")
    if glf_code is not None:
        cargs.append(glf_code)
    cargs.append("-dataTable")
    cargs.append(data_table)
    ret = V3dMvmOutputs(
        root=execution.output_file("."),
        outfile_head=execution.output_file(prefix + "+tlrc.HEAD"),
        outfile_brik=execution.output_file(prefix + "+tlrc.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMvmOutputs",
    "V_3D_MVM_METADATA",
    "v_3d_mvm",
]
